#!/bin/sh
#  Author:  Joseph L. Kaiser - jlkaiser@fnal.gov
#  Date:  1/16/02
#
#  The farms.after.rpms.sh script was created in it's most workable form
#  on 1/16/02.  This script is for a FHRL 6.1.2 install and may not be
#  applicable to the 7.1 or 7.2 installs.
#  
#  The script does the following:
#  
#  1.  Formats any additional data drives.
#  2.  Checks the /proc filesystem to determine which drive is the cdrom
#      and which are IDE hard drives.  (This only works for IDE disks.)
#  3.  Get the IP address of the machine and determine the hostname via nslookup.
#  4.  Determine which CMS IO node this cluster will receive nfs mounted directories 
#      from.
#  5.  Build the bottom half of the fstab file for possible different drive configs.
#  6   Concatenate the proper bottom half of the fstab file into /etc/fstab.
#  7.  Make directories, change permissions.
#  8.  Set eth0 to full duplex
#  9.  Put in the proper rc script for fbsng.
#  10.  Put the yp host into the hosts file.
#  11.  Put in the other name server
#  12.  Fix the nsswitch file to get your hostnames via DNS
#  13.  Turn off unnecessary services.
#  



#  Format any drives additional to the main disk and not the cdrom.
#  Put this in one large partition.

for drive in `ls /proc/ide | awk '/hd?/'`
do
mediatype=`cat /proc/ide/$drive/media`
   if [ "$drive" != "hda" -a "$mediatype" = "disk" ]
        then
        `/sbin/sfdisk -q -L /dev/${drive} << EOF
        ;`
         diskpartition=`/sbin/sfdisk -l /dev/${drive} | \
          grep Linux | awk '{print $1}'`
           /sbin/mke2fs -b 4096 -m 2 ${diskpartition}
      elif [ "$mediatype" = "cdrom" ]; then
              :
         else
         :
    fi
    done

#  Figure out what media type each drive higher than hda is - HD vs. CD-ROM

getmediatype_hdb () {
mediatype=`cat /proc/ide/hdb/media`
echo $mediatype
}

getmediatype_hdc () {
mediatype=`cat /proc/ide/hdc/media`
echo $mediatype
}

getmediatype_hdd () {
mediatype=`cat /proc/ide/hdd/media`
echo $mediatype
}


#  Get the IP address of the machine and determine the hostname via nslookup.
#  This is needed to build the NFS half of the fstab file.
IPADDR=`/bin/grep IPADDR /etc/sysconfig/network-scripts/ifcfg-eth0 | cut -d= -f 2`

THISHOST=`nslookup $IPADDR | grep -i "Name:" | cut -d":" -f 2 | sed "s/^ *//g"`
NICKNAME=`echo $THISHOST | cut -d. -f 1`

#  Determine which CMS IO node this cluster will receive nfs mounted directories 
#  from.
case $THISHOST in
   gyoza*)  MYHOST='ramen';;
   fry*)  MYHOST='bigmac';;
   popcrn*)  MYHOST='gallo';;
   *) MYHOST='gallo';;
esac


# Build the bottom half of the fstab file for possible different drive configs.
fstab_hdb="
/dev/hdb1               /data1                  ext2    defaults 1 1
/dev/hdc1               /data2                  ext2    defaults 1 1
$MYHOST:/fnal/ups        /fnal/ups       nfs     rsize=8192,wsize=8192,ro,hard,intr,bg 0 0
$MYHOST:/usr/local	/usr/local     nfs     rsize=8192,wsize=8192,ro,soft,bg,intr 0 0
$MYHOST:/data     /data                           nfs     rsize=8192,wsize=8192,rw,hard,bg,intr 0 0
$MYHOST:/home/farms	 /home/farms	nfs     rsize=8192,wsize=8192,rw,hard,bg,intr 0 0
#stkensrv1:/cms          /pnfs/cms               nfs     user,intr,hard,bg,rw,noac 0 0"

fstab_hdd="
/dev/hdc1               /data1                  ext2    defaults 1 1
/dev/hdd1               /data2                  ext2    defaults 1 1
$MYHOST:/fnal/ups        /fnal/ups       nfs     rsize=8192,wsize=8192,ro,hard,intr,bg 0 0
$MYHOST:/usr/local	/usr/local     nfs     rsize=8192,wsize=8192,ro,soft,bg,intr 0 0
$MYHOST:/data     /data                           nfs     rsize=8192,wsize=8192,rw,hard,bg,intr 0 0
$MYHOST:/home/farms	 /home/farms	nfs     rsize=8192,wsize=8192,rw,hard,bg,intr 0 0
#stkensrv1:/cms          /pnfs/cms               nfs     user,intr,hard,bg,rw,noac 0 0"

#  Concatenate the proper bottom half of the fstab file into /etc/fstab.

if [ `getmediatype_hdb` = "disk" -a `getmediatype_hdd` = "cdrom" ]
  then
    echo "$fstab_hdb" >> /etc/fstab
elif [ `getmediatype_hdd` = "disk" -a `getmediatype_hdb` = "cdrom" ]
  then
    echo "$fstab_hdd" >> /etc/fstab
else 
    :
fi


# Make directories, change permissions.
/bin/mkdir -p /fnal/ups
/bin/mkdir -p /pnfs/cms
/bin/mkdir -p /home/farms
/bin/mkdir -p /var/adm/krb5/farms
/bin/mkdir -p -m 700 /usr/spool/objy
/bin/mkdir -m 775 /data
/bin/mkdir /data1
/bin/mkdir /data2
/bin/mount /data1
/bin/mount /data2
/bin/chown 9811.5063 /data
/bin/chown 9811.5063 /data1
/bin/chown 9811.5063 /data2
/bin/chmod 775 /data1
/bin/chmod 775 /data2
/bin/umount /data1
/bin/umount /data2

/bin/chmod 1777 /tmp

/bin/ln -s /home/farms/ngop/ngop_root/worker /var/ngop

# Set eth0 to full duplex
/bin/cp /etc/conf.modules /etc/conf.modules.orig
/bin/echo "alias eth0 eepro100
alias scsi_hostadapter aic7xxx
options eepro100 options=0x30" > /etc/conf.modules


# Put in the proper rc script for fbsng.
/bin/echo '#!/bin/sh

# FBSNG farm node startup script template.
# Administrator: edit the following definitions:
# chkconfig: 345 98 20
# description:  Startup for fbsng functions

farms_root=/home/farms/fbsng_root


case "$1" in

'start')
	# start launcher
	${farms_root}/bin/start_lch.sh
	;;
	
'stop')
	;;
	
*)
	echo "usage: $0 {start|stop}"
	;;
esac

exit 0' > /etc/rc.d/init.d/fbsng

/bin/chmod 755 /etc/rc.d/init.d/fbsng

# put the yp host into the hosts file.
/bin/cp /etc/hosts /etc/hosts.orig

/bin/echo "127.0.0.1       localhost.localdomain localhost
$IPADDR		$THISHOST	$NICKNAME	
131.225.206.41          cmsun1.fnal.gov                 cmsun1" > /etc/hosts

# put in the other name server
/bin/cp /etc/resolv.conf /etc/resolv.conf.orig
/bin/echo "search fnal.gov
nameserver 131.225.8.120
nameserver 131.225.17.150" > /etc/resolv.conf

# hosts.allow and hosts.deny

/bin/cp /etc/hosts.allow /etc/hosts.allow.orig
/bin/cp /etc/hosts.deny /etc/hosts.allow.deny
/bin/echo '#
# hosts.allow   This file describes the names of the hosts which are
#               allowed to use the local INET services, as decided
#               by the '/usr/sbin/tcpd' server.
#
# 

portmap: 131.225.0.0/255.255.0.0 LOCAL 127.0.0.1
rpc.mountd: 131.225. LOCAL 127.0.0.1
ALL: .fnal.gov 131.225. LOCAL 127.0.0.1 : banners /etc/banners
sshd: ALL' > /etc/hosts.allow

/bin/echo '#
# hosts.deny    This file describes the names of the hosts which are
#               *not* allowed to use the local INET services, as decided
#               by the '/usr/sbin/tcpd' server.
#
# The portmap line is redundant, but it is left to remind you that
# the new secure portmap uses hosts.deny and hosts.allow.  In particular
# you should know that NFS uses portmap!


ALL: ALL except 127.0.0.1 : banners /etc/banners' > /etc/hosts.deny


# yp.conf

#echo 'domain cms.fnal.gov ypserver cmsun1.fnal.gov' >> /etc/yp.conf
/bin/cp /etc/CMSfarm/configfiles/yp.conf /etc/yp.conf

/bin/cp /etc/CMSfarm/configfiles/k5login /root/.k5login

# fix the nsswitch file to get your hostnames via DNS

/bin/cp /etc/nsswitch.conf /etc/nsswitch.conf.orig

/bin/sed "s/\(^hosts: *\)\(files *\)\(nisplus nis \)\(dns\)/\1\4 \2/g" /etc/nsswitch.conf.orig > /etc/nsswitch.conf

# Turn off unnecessary services.
/sbin/chkconfig --level 345 fbsng on
/sbin/chkconfig --level 345 facct on
/sbin/chkconfig --level 345 ultradma on
/sbin/chkconfig --level 345 autofs on
/sbin/chkconfig --level 345 portmap on
/sbin/chkconfig --level 345 rstatd on
/sbin/chkconfig --level 345 ypbind on

/sbin/chkconfig --del sendmail
/sbin/chkconfig --del kudzu
/sbin/chkconfig --del identd
/sbin/chkconfig --del apmd
/sbin/chkconfig --del gpm
/sbin/chkconfig --add nfslock


/usr/sbin/install-pcp-config generic

rm -f /usr/man/man1/rec.1

rpm -e kernel-pcmcia-cs
/etc/cron.daily/slocate.cron
echo "/usr/X11R6/lib" >> /etc/ld.so.conf
echo "/usr/i486-linux-libc5/lib" >> /etc/ld.so.conf
/sbin/ldconfig

rm -f /usr/man/man1/rec.1
rm -f /usr/man/man8/rpc.mountd.8.gz
